@@ -162,6 +162,7 @@ static char        *ok_options[] = {
     "--ext",
     "--help",
     "--css",
+    "--js",
     "--version",
     "-c",
     "--lock",
@@ -178,6 +179,7 @@ static char        *ok_options[] = {
     "--tabstops",
     "--syntaxcolors",
     "--syntaxcolors_enable",
+    "--keywords_case_insensitive",
     "--dotname",
     "--masterindex",
     "--sourceindex",
